import { ITextEditorSelection } from '@vscode/monaco-editor/esm/vs/platform/editor/common/editor';
import { IEditor as ICodeEditor, IEditorViewState, ScrollType, IEditor } from '@vscode/monaco-editor/esm/vs/editor/common/editorCommon';
import { IBaseResourceInput, IEditorOptions, IEditorActivation as EditorActivation, IEditorOpenContext as EditorOpenContext, ITextEditorOptions_Input as ITextEditorOptions, ITextEditorSelectionRevealType as TextEditorSelectionRevealType } from '@workbench-stack/core';
export declare const DEFAULT_EDITOR_PART_OPTIONS: IEditorPartOptions;
export declare function getEditorPartOptions(config: IWorkbenchEditorConfiguration): IEditorPartOptions;
export interface IWorkbenchEditorConfiguration {
    workbench: {
        editor: IEditorPartConfiguration;
        iconTheme: string;
    };
}
interface IEditorPartConfiguration {
    showTabs?: boolean;
    highlightModifiedTabs?: boolean;
    tabCloseButton?: 'left' | 'right' | 'off';
    tabSizing?: 'fit' | 'shrink';
    focusRecentEditorAfterClose?: boolean;
    showIcons?: boolean;
    enablePreview?: boolean;
    enablePreviewFromQuickOpen?: boolean;
    closeOnFileDelete?: boolean;
    openPositioning?: 'left' | 'right' | 'first' | 'last';
    openSideBySideDirection?: 'right' | 'down';
    closeEmptyGroups?: boolean;
    revealIfOpen?: boolean;
    swipeToNavigate?: boolean;
    labelFormat?: 'default' | 'short' | 'medium' | 'long';
    restoreViewState?: boolean;
}
export interface IEditorPartOptions extends IEditorPartConfiguration {
    iconTheme?: string;
}
export declare class EditorOptions implements IEditorOptions {
    static create(settings: IEditorOptions): EditorOptions;
    preserveFocus: boolean | undefined;
    activation: EditorActivation | undefined;
    forceReload: boolean | undefined;
    revealIfVisible: boolean | undefined;
    revealIfOpened: boolean | undefined;
    pinned: boolean | undefined;
    sticky: boolean | undefined;
    index: number | undefined;
    inactive: boolean | undefined;
    ignoreError: boolean | undefined;
    override?: false | string;
    context: EditorOpenContext | undefined;
    overwrite(options: IEditorOptions): EditorOptions;
}
export declare class TextEditorOptions extends EditorOptions implements ITextEditorOptions {
    selection: ITextEditorSelection | undefined;
    editorViewState: IEditorViewState | undefined;
    selectionRevealType: TextEditorSelectionRevealType | undefined;
    static from(input?: IBaseResourceInput): TextEditorOptions | undefined;
    static create(options?: ITextEditorOptions): TextEditorOptions;
    overwrite(options: ITextEditorOptions): TextEditorOptions;
    hasOptionsDefined(): boolean;
    static fromEditor(editor: ICodeEditor, settings?: IEditorOptions): TextEditorOptions;
    apply(editor: IEditor, scrollType: ScrollType): boolean;
}
export {};
